@@ -1,10 +1,11 @@
+import logging
 from logging import Formatter
 from logging.handlers import RotatingFileHandler
 
 
-def setup_file_logger(**kwargs):
+def setup_file_logger(logfile='orka.log'):
     file_handler = RotatingFileHandler(
-        kwargs.get('logfile', 'orka.log'),
+        logfile,
         maxBytes=1024
     )
     file_handler.setFormatter(Formatter(
